"matMeans" <-
function (lis) {
    matSums(lis) / length(lis)
}

